/* Compile options:  -ml (Large code model) */

#include <stdio.h>
#include "main.h"

#pragma config WDT = OFF

int i = 0;
const char j;

void main (void)
{
  printf("Hello, world!\n");
  c1 = 'a';
  while (i!=10) i++;
}
